"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EscrwWorldsDeltaProcessorTaskMapper = exports.EscrwWorldsDeltaMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const enums_1 = require("../../domain/enums");
const escrows_mapper_1 = require("./escrows.mapper");
class EscrwWorldsDeltaMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    fromEntity(entity) {
        let entityData;
        switch (entity.table) {
            case enums_1.EscrwWorldsTableName.Escrows:
                entityData = new escrows_mapper_1.EscrowsMongoMapper().fromEntity(entity.data);
                break;
        }
        const model = {
            block_timestamp: entity.blockTimestamp,
            block_num: new aw_storage_mongodb_1.MongoDB.Long(entity.blockNumber),
            code: entity.code,
            scope: entity.scope,
            table: entity.table,
            data: entityData,
            payer: entity.payer,
            primary_key: new aw_storage_mongodb_1.MongoDB.Long(entity.primaryKey),
            present: entity.present,
        };
        if (entity.id && aw_storage_mongodb_1.MongoDB.ObjectId.isValid(entity.id)) {
            model._id = new aw_storage_mongodb_1.MongoDB.ObjectId(entity.id);
        }
        return model;
    }
    toEntity(mongoModel) {
        let data;
        switch (mongoModel.table) {
            case enums_1.EscrwWorldsTableName.Escrows:
                data = new escrows_mapper_1.EscrowsMongoMapper().toEntity(mongoModel.data);
                break;
        }
        const { _id, block_num, code, scope, table, payer, primary_key, present, block_timestamp, } = mongoModel;
        return new aw_core_1.ContractDelta(_id.toString(), (0, aw_core_1.parseToBigInt)(block_num), code, scope, table, data, payer, (0, aw_core_1.parseToBigInt)(primary_key), present, block_timestamp);
    }
}
exports.EscrwWorldsDeltaMongoMapper = EscrwWorldsDeltaMongoMapper;
class EscrwWorldsDeltaProcessorTaskMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('method not implemented');
    }
    toEntity(rawModel) {
        let data;
        switch (rawModel.table) {
            case enums_1.EscrwWorldsTableName.Escrows:
                data = new escrows_mapper_1.EscrowsRawMapper().toEntity(rawModel.data);
                break;
        }
        const { block_num, code, scope, table, payer, primary_key, present, block_timestamp, } = rawModel;
        return new aw_core_1.ContractDelta('', (0, aw_core_1.parseToBigInt)(block_num), code, scope, table, data, payer, (0, aw_core_1.parseToBigInt)(primary_key), present, block_timestamp);
    }
}
exports.EscrwWorldsDeltaProcessorTaskMapper = EscrwWorldsDeltaProcessorTaskMapper;
